@@ -2,11 +2,11 @@
  *
  * pgsp_explain.h: extracted code from explain.c for explain of triggers.
  *
- * Copyright (c) 2008-2022, PostgreSQL Global Development Group
- * Copyright (c) 2012-2022, NIPPON TELEGRAPH AND TELEPHONE CORPORATION
+ * Copyright (c) 2008-2013, PostgreSQL Global Development Group
+ * Copyright (c) 2012-2015, NIPPON TELEGRAPH AND TELEPHONE CORPORATION
  *
  * IDENTIFICATION
- *	  pg_store_plans/pgsp_explain.h
+ *	  pg_store_plan/pgsp_explain.h
  *
  *-------------------------------------------------------------------------
  */
