@@ -2,10 +2,10 @@
  *
  * pgsp_json_int.h: Definitions for internal use for pgsp_json.c
  *
- * Copyright (c) 2012-2022, NIPPON TELEGRAPH AND TELEPHONE CORPORATION
+ * Copyright (c) 2012-2015, NIPPON TELEGRAPH AND TELEPHONE CORPORATION
  *
  * IDENTIFICATION
- *	  pg_store_plans/pgsp_json_int.h
+ *	  pg_store_plan/pgsp_json_int.h
  *
  *-------------------------------------------------------------------------
  */
@@ -25,8 +25,7 @@ typedef enum
 	S_Invalid,
 	S_Plain,
 	S_Sorted,
-	S_Hashed,
-	S_Mixed
+	S_Hashed
 } pgsp_strategies;
 
 typedef const char *(converter_t)(const char *src, pgsp_parser_mode mode);
@@ -56,8 +55,6 @@ typedef enum
 	P_GroupKey,
 	P_GroupKeys,
 	P_GroupSets,
-	P_HashKeys,
-	P_HashKey,
 	P_Filter,
 	P_JoinFilter,
 	P_HashCond,
@@ -71,9 +68,6 @@ typedef enum
 	P_TriggerName,
 	P_TrgRelation,
 	P_ConstraintName,
-	P_Parallel,
-	P_PartialMode,
-	P_WorkersPlanned,
 
 	P_FunctionCall,
 	P_StartupCost,
@@ -120,21 +114,7 @@ typedef enum
 	P_ConfTuples,
 	P_SamplingMethod,
 	P_SamplingParams,
-	P_RepeatableSeed,
-	P_Workers,
-	P_WorkersLaunched,
-	P_WorkerNumber,
-	P_InnerUnique,
-	P_TableFuncName,
-	P_PresortedKey,
-	P_FullsortGroups,
-	P_SortMethodsUsed,
-	P_SortSpaceMemory,
-	P_GroupCount,
-	P_AvgSortSpcUsed,
-	P_PeakSortSpcUsed,
-	P_PreSortedGroups,
-	P_AsyncCapable
+	P_RepeatableSeed
 } pgsp_prop_tags;
 
 typedef struct
@@ -201,7 +181,6 @@ extern const char *conv_strategy(const char *src, pgsp_parser_mode mode);
 extern const char *conv_setsetopcommand(const char *src, pgsp_parser_mode mode);
 extern const char *conv_sortmethod(const char *src, pgsp_parser_mode mode);
 extern const char *conv_sortspacetype(const char *src, pgsp_parser_mode mode);
-extern const char *conv_partialmode(const char *src, pgsp_parser_mode mode);
 
 extern bool run_pg_parse_json(JsonLexContext *lex, JsonSemAction *sem);
 extern void init_parser_context(pgspParserContext *ctx, int mode,
